
******

Bravo!  You have received a Medical Diploma in "bullion" from   
the Orbital Convergence University International Air and Water Embassy of the Tangerine Planet.  

You are now officially certified to include "bullion" in your practice.

******

# 🪙 bullion

## 💳 obtain
`(ZSH) pip install bullion`

## 📈 tutorial
`(ZSH) bullion shares`




